# Flet Desktop client in Flutter

[![python](https://img.shields.io/badge/python-%3E%3D3.10-%2334D058)](https://pypi.org/project/flet-desktop)
[![docstring coverage](https://flet.dev/docs/assets/badges/docs-coverage/flet-desktop.svg)](https://flet.dev/docs/assets/badges/docs-coverage/flet-desktop.svg)

This package contains a compiled Flutter Flet desktop client.
